.. 2019-02-21 sonofeft 24a56447c92f538c8fff57a8237f35312f5b67d1
   Maintain spacing of "History" and "GitHub Log" titles

History
=======

GitHub Log
----------

* Feb 21, 2019
    - (by: sonofeft) 
        - added named_s_hash, dyna_grid_xN, priority_queue, some TODO
* Feb 20, 2019
    - (by: sonofeft) 
        - single line description in setup.py required
        - fixed pickle file inclusion in PyPI
        - First Git Commit

* 2019-02-19 23:35 Charlie Taylor
    - added more chapter 8 figures to docs

* 2019-02-19 02:02 Charlie Taylor
    - got Dyna-Q to work

* 2019-02-14 16:39 Charlie Taylor
    - clarified policy evaluation for nsteps

* 2019-02-14 12:53 Charlie Taylor
    - ran all the __name__==__main__ tests

* 2019-02-14 12:51 Charlie Taylor
    - rewrote nstep_walker

* 2019-02-13 15:36 Charlie Taylor
    - added SARSA to n-step walker

* 2019-02-11 09:29 Charlie Taylor
    - updates to chapter 6 docs

* 2019-02-11 01:18 Charlie Taylor
    - lots of cleanup and windy gridworld docs

* 2019-02-10 22:17 Charlie Taylor
    - cleaned up loop_counter

* 2019-02-07 17:49 Charlie Taylor
    - finished first draft of chapter 5 docs

* 2019-02-07 03:33 Charlie Taylor
    - added to chapter 5, MC docs page

* 2019-02-06 16:02 Charlie Taylor
    - got rid of loop_counter in MC funcs

* 2019-02-06 10:27 Charlie Taylor
    - added randomized iteration to MC functions

* 2019-02-06 01:49 Charlie Taylor
    - MC routines needed max_num_episodes clarified

* 2019-02-06 01:01 Charlie Taylor
    - working on docs and policy diagram

* 2019-02-05 01:48 Charlie Taylor
    - added sample simulation

* 2019-02-04 21:39 Charlie Taylor
    - found correction in Zhang car rental

* 2019-02-03 10:49 Charlie Taylor
    - more docs added

* 2019-02-02 23:05 Charlie Taylor
    - added arrows to policy diagram

* 2019-02-02 17:47 Charlie Taylor
    - moved GenericLayout up into EnvBaseline call for most mdp

* 2019-02-02 15:03 Charlie Taylor
    - created sample mdp for docs

* 2019-02-01 02:05 Charlie Taylor
    - started MC docs and added blackjack

* 2019-01-31 10:06 Charlie Taylor
    - added td_funcs and removed state_value_alpha_coll

* 2019-01-31 02:10 Charlie Taylor
    - doc updates

* 2019-01-31 00:53 Charlie Taylor
    - added documentation for chap 3 and 4

* 2019-01-30 08:52 Charlie Taylor
    - a bunch of reorganizing

* 2019-01-30 02:00 Charlie Taylor
    - migrating examples into IntroRL

* 2019-01-29 23:29 Charlie Taylor
    - added some defined MDP environments

* 2019-01-29 15:03 Charlie Taylor
    - Initial Empty Project

* Jan 29, 2019
    - (by: sonofeft)
        - First Created IntroRL with PyHatch
